@@ -3,7 +3,13 @@ from ai_dashboard.tabs.data_report.blocks.base import BaseBlock
 
 
 class Image(BaseBlock):
-    def __init__(self, image_url: str, title: str = "", width_percentage: int = 100, upload: bool = False):
+    def __init__(
+        self,
+        image_url: str,
+        title: str = "",
+        width_percentage: int = 100,
+        upload: bool = False,
+    ):
         self.title = title
         self.image_url = image_url
         self.upload = upload
@@ -103,7 +109,9 @@ class Video(BaseBlock):
 
 
 class PDF(BaseBlock):
-    def __init__(self, pdf_url: str, title: str = "", width_percentage: int = 100, analysis={}):
+    def __init__(
+        self, pdf_url: str, title: str = "", width_percentage: int = 100, analysis={}
+    ):
         self.title = title
         self.pdf_url = pdf_url
         self.block = {
